<?php
declare(strict_types=1);

namespace Inti\Redis\Container;

use Psr\Container\ContainerInterface;
use Redis;
use RuntimeException;
use function is_int;

/**
 * Class RedisFactory
 *
 * @package Inti\Redis\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-redis
 */
final class RedisFactory
{
    public function __invoke(ContainerInterface $container): Redis
    {
        $config = $container->has('config') ? $container->get('config') : [];

        $redis = new Redis();
        $redis->pconnect($config['redis']['host'] ?? '');

        if (!is_int($config['redis']['db'] ?? null)) {
            throw new RuntimeException('Redis database not set.');
        }

        $redis->select($config['redis']['db']);

        return $redis;
    }
}
